==> hibernate-validator-4.3.4.Final-redhat-1-sources.jar: org/hibernate/validator/internal/engine/groups/ValidationOrder.java <==
/*
* JBoss, Home of Professional Open Source
* Copyright 2009, Red Hat, Inc. and/or its affiliates, and individual contributors
* by the @authors tag. See the copyright.txt in the distribution for a
* full listing of individual contributors.
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
* http://www.apache.org/licenses/LICENSE-2.0
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/
package org.hibernate.validator.internal.engine.groups;

import java.util.Collections;
import java.util.Iterator;
import java.util.List;

import javax.validation.GroupDefinitionException;

/**
 * Interface defining the methods needed to execute groups and sequences in the right order.
 *
 * @author Hardy Ferentschik
 */
public interface ValidationOrder {

	/**
	 * A {@link org.hibernate.validator.internal.engine.groups.ValidationOrder} which contains a single sequence which
	 * in turn contains a single group, {@code Default}.
	 */
	ValidationOrder DEFAULT_SEQUENCE = new DefaultValidationOrder();

	static class DefaultValidationOrder implements ValidationOrder {

		private final List<Sequence> defaultSequences;

		private DefaultValidationOrder() {
			defaultSequences = Collections.singletonList( Sequence.DEFAULT );
		}

		@Override
		public Iterator<Group> getGroupIterator() {
			// Not using emptyIterator() to stay on 1.6 language level
			return Collections.<Group>emptyList().iterator();
		}

		@Override
		public Iterator<Sequence> getSequenceIterator() {
			return defaultSequences.iterator();
		}

		@Override
		public void assertDefaultGroupSequenceIsExpandable(List<Class<?>> defaultGroupSequence) throws GroupDefinitionException {
		}
	}

	public Iterator<Group> getGroupIterator();

	public Iterator<Sequence> getSequenceIterator();

	/**
	 * Asserts that the default group sequence of the validated bean can be expanded into the sequences which needs to
	 * be validated.
	 *
	 * @param defaultGroupSequence the default group sequence of the bean currently validated
	 *
	 * @throws GroupDefinitionException in case {@code defaultGroupSequence} cannot be expanded into one of the group sequences
	 * which need to be validated
	 */
	public void assertDefaultGroupSequenceIsExpandable(List<Class<?>> defaultGroupSequence)
			throws GroupDefinitionException;
}

==> hibernate-validator-5.2.5.Final-redhat-1-sources.jar: org/hibernate/validator/internal/engine/groups/ValidationOrder.java <==
/*
 * Hibernate Validator, declare and validate application constraints
 *
 * License: Apache License, Version 2.0
 * See the license.txt file in the root directory or <http://www.apache.org/licenses/LICENSE-2.0>.
 */
package org.hibernate.validator.internal.engine.groups;

import java.util.Collections;
import java.util.Iterator;
import java.util.List;

import javax.validation.GroupDefinitionException;

/**
 * Interface defining the methods needed to execute groups and sequences in the right order.
 *
 * @author Hardy Ferentschik
 */
public interface ValidationOrder {

	Iterator<Group> getGroupIterator();

	Iterator<Sequence> getSequenceIterator();

	/**
	 * Asserts that the default group sequence of the validated bean can be expanded into the sequences which needs to
	 * be validated.
	 *
	 * @param defaultGroupSequence the default group sequence of the bean currently validated
	 *
	 * @throws GroupDefinitionException in case {@code defaultGroupSequence} cannot be expanded into one of the group sequences
	 * which need to be validated
	 */
	void assertDefaultGroupSequenceIsExpandable(List<Class<?>> defaultGroupSequence)
			throws GroupDefinitionException;

	/**
	 * A {@link org.hibernate.validator.internal.engine.groups.ValidationOrder} which contains a single sequence which
	 * in turn contains a single group, {@code Default}.
	 */
	ValidationOrder DEFAULT_SEQUENCE = new DefaultValidationOrder();

	static class DefaultValidationOrder implements ValidationOrder {

		private final List<Sequence> defaultSequences;

		private DefaultValidationOrder() {
			defaultSequences = Collections.singletonList( Sequence.DEFAULT );
		}

		@Override
		public Iterator<Group> getGroupIterator() {
			// Not using emptyIterator() to stay on 1.6 language level
			return Collections.<Group>emptyList().iterator();
		}

		@Override
		public Iterator<Sequence> getSequenceIterator() {
			return defaultSequences.iterator();
		}

		@Override
		public void assertDefaultGroupSequenceIsExpandable(List<Class<?>> defaultGroupSequence) throws GroupDefinitionException {
		}
	}
}
